@@ -1,6 +1,6 @@
 #' Instantiate a Scala Bridge
 #'
-#' This function creates an instance of an rscala bridge.  Details on this
+#' This function creates an instance of a Scala bridge.  Details on this
 #' function (and the rscala package as a whole) are provided in the package
 #' vignette and the associated paper in the \emph{Journal of Statistical
 #' Software}. See the reference below.
@@ -17,17 +17,17 @@
 #'   JAR files are added to the runtime classpath.
 #' @param serialize.output Logical indicating whether Scala output should be
 #'   serialized back to R.  This is slower and probably only needed on Windows.
-#' @param stdout Whether "standard output" results that are not serialized
-#'   should be sent.  \code{TRUE} or \code{""} sends output to the \R console
-#'   (although that may not work on Windows).  \code{FALSE} or \code{NULL}
-#'   discards the output.  Otherwise, this is the name of the file that receives
-#'   the output.
+#' @param stdout When \code{serialize.output == FALSE}, this argument influences
+#'   where "standard output" results should be sent.  \code{TRUE} or \code{""}
+#'   sends output to the \R console (although that may not work on Windows).
+#'   \code{FALSE} or \code{NULL} discards the output.  Otherwise, this is the
+#'   name of the file that receives the output.
 #' @param stderr Same as \code{stdout}, except influences the "standard error".
 #' @param port If \code{0}, two random ports are selected.  Otherwise,
 #'   \code{port} and \code{port+1} are used to the TCP/IP connections.
 #' @param heap.maximum String giving Scala's heap maximum, e.g., "8G" or "512M".
 #'   The value here supersedes that from \code{\link{scalaMemory}}. Without this
-#'   being set in either \code{\link{scala}} or \code{\link{scalaMemory}}, the
+#'   being set by either \code{\link{scala}} or \code{\link{scalaMemory}}, the
 #'   heap maximum will be 90\% of the available RAM.
 #' @param command.line.arguments A character vector of extra command line
 #'   arguments to pass to the Scala executable, where each element corresponds
@@ -35,8 +35,8 @@
 #' @param debug (Developer use only.)  Logical indicating whether debugging
 #'   should be enabled.
 #'
-#' @return Returns an rscala bridge.
-#' @references {David B. Dahl (2018). “Integration of R and Scala Using rscala.”
+#' @return Returns a Scala bridge.
+#' @references {David B. Dahl (2019). "Integration of R and Scala Using rscala."
 #'   Journal of Statistical Software, in editing. https://www.jstatsoft.org}
 #' @seealso \code{\link{close.rscalaBridge}}, \code{\link{scalaMemory}}
 #'   \code{\link{scalaPushRegister}}, \code{\link{scalaPullRegister}}
@@ -62,14 +62,14 @@ scala <- function(JARs=character(),
                   heap.maximum=NULL,
                   command.line.arguments=character(0),
                   debug=FALSE) {
-  stdout <- if ( missing(stdout) && ( Sys.getenv("RSCALA_STDOUT") != "" ) ) {
+  if ( missing(stdout) && ( Sys.getenv("RSCALA_STDOUT") != "" ) ) {
     x <- Sys.getenv("RSCALA_STDOUT")
-    if ( x %in% c("TRUE","FALSE") ) as.logical(x) else x
+    stdout <- if ( x %in% c("TRUE","FALSE") ) as.logical(x) else x
   }
   if ( identical(stdout,TRUE) ) stdout <- ""
-  stderr <- if ( missing(stderr) && ( Sys.getenv("RSCALA_STDERR") != "" ) ) {
+  if ( missing(stderr) && ( Sys.getenv("RSCALA_STDERR") != "" ) ) {
     x <- Sys.getenv("RSCALA_STDERR")
-    if ( x %in% c("TRUE","FALSE") ) as.logical(x) else x
+    stderr <- if ( x %in% c("TRUE","FALSE") ) as.logical(x) else x
   }
   if ( identical(stderr,TRUE) ) stderr <- ""
   debug <- if ( missing(debug) && ( Sys.getenv("RSCALA_DEBUG") != "" ) ) {
@@ -85,7 +85,7 @@ scala <- function(JARs=character(),
   sConfig <- tryCatch(scalaConfig(FALSE), error=function(e) list(error=e))
   if ( is.null(sConfig$error) ) {
     scalaMajor <- sConfig$scalaMajorVersion
-    rscalaJAR <- shQuote(list.files(system.file(file.path("java",paste0("scala-",scalaMajor)),package="rscala",mustWork=FALSE),".*\\.jar$",full.names=TRUE))
+    rscalaJAR <- shQuote(paste0(list.files(system.file(file.path("java",paste0("scala-",scalaMajor)),package="rscala",mustWork=FALSE),".*\\.jar$",full.names=TRUE),collapse=":"))
     if ( length(rscalaJAR) == 0 ) {
       sConfig$error <- list(message=paste0("\n\n<<<<<<<<<<\n<<<<<<<<<<\n<<<<<<<<<<\n\nScala version ",sConfig$scalaFullVersion," is not among the support versions: ",paste(names(scalaVersionJARs()),collapse=", "),".\nPlease run 'rscala::scalaConfig(reconfig=TRUE)'\n\n>>>>>>>>>>\n>>>>>>>>>>\n>>>>>>>>>>\n"))
     } else {
